pub enum SPPFNode<L: GrammarLabel> {
Dummy,
Symbol(L::Symbol, usize, usize, Vec<SPPFNodeIndex>),
Intermediate(L, usize, usize, Vec<SPPFNodeIndex>),
Packed(L, usize, Vec<SPPFNodeIndex>),
}Expand description
Binary SPPF Node structure.
Each node can be one of: Dummy, Symbol, Intermediate and Packed.
Symbol is a Terminal or a Nonterminal.
Intermediate is a grammar rule with position.
Packed means different derivations of the same grammar rule.
Each grammar rule possible position corresponds to a label. So store labels for Intermediate and Packed rules.
Variants
Dummy
$ node in original paper
Symbol(L::Symbol, usize, usize, Vec<SPPFNodeIndex>)
(symbol, left, right, children)
Intermediate(L, usize, usize, Vec<SPPFNodeIndex>)
(label, left, right, children)
Packed(L, usize, Vec<SPPFNodeIndex>)
(label, split, children)
Implementations
Sourceimpl<L: GrammarLabel> SPPFNode<L>
impl<L: GrammarLabel> SPPFNode<L>
Sourcepub fn right_extent(&self) -> usize
pub fn right_extent(&self) -> usize
Get right extent of the node, panics if it doesn’t have it.
Sourcepub fn left_extent(&self) -> usize
pub fn left_extent(&self) -> usize
Get left extent of the node, panics if it doesn’t have it.
Sourcepub fn children(&self) -> Option<&Vec<SPPFNodeIndex>>
pub fn children(&self) -> Option<&Vec<SPPFNodeIndex>>
Get children node references.