[][src]Struct gll_pg_core::EdgeReference

pub struct EdgeReference<'a, E, Ix = u32> where
    E: 'a, 
{ /* fields omitted */ }

Re-exported petgraph structs to avoid requiring dependency of generated code on it. Reference to a Graph edge.

Methods

impl<'a, Ix, E> EdgeReference<'a, E, Ix> where
    Ix: IndexType
[src]

Re-exported petgraph structs to avoid requiring dependency of generated code on it.

pub fn weight(&self) -> &'a E[src]

Access the edge’s weight.

NOTE that this method offers a longer lifetime than the trait (unfortunately they don't match yet).